This function uses the API for the World Historical Gazeteer to geolocate place names.
It takes the place name and region as inputs and returns a data frame with results,
primarily the longitude and latitude.
Usage
geolocate(df, place = "place", iso = "iso")
Value
A data frame of the geospatial data
Arguments
df
A data frame with two columns, places names and two-letter ISO codes for regions